@@ -14,11 +14,13 @@ public:
     ListViewDelegate(QWidget* parent = 0);
     virtual ~ListViewDelegate();
 
-    enum datarole {headerRole = Qt::UserRole + 100, subHeaderLeftJustifyRole = Qt::UserRole+101, subHeaderRightJustifyRole = Qt::UserRole+102, iconRole = Qt::UserRole+103, highlightItemTextRole = Qt::UserRole+104};
+    enum datarole {headerRole = Qt::UserRole + 100, subHeaderLeftJustifyRole = Qt::UserRole+101, subHeaderRightJustifyRole = Qt::UserRole+102, iconRole = Qt::UserRole+103, highlightItemTextRole = Qt::UserRole+104,
+                   headerItemRole = Qt::UserRole + 105, headerItemColorRole = Qt::UserRole + 106, headerItemSizeRole = Qt::UserRole + 107 , customDataRole = Qt::UserRole + 108};
 
     void setHeaderFontPointSize(int size);
     void setSubHeaderFontPointSize(int size);
     void setItemTextHighlightColor(const QColor& color);
+    void setItemTextDisabledColor(const QColor& color);
 
 protected:
 
@@ -31,9 +33,13 @@ protected:
 private:
 
     int m_HeaderFontPointSize;
+
     int m_SubHeaderFontPointSize;
+
     QColor m_TextHighlightColor;
 
+    QColor m_TextDisabledColor;
+
     };
 
 
