@@ -401,15 +401,29 @@ void TrackView::addTrackListModelItem(Spotify::Track* track, qint32 pos)
     QIcon trackTypeIcon(iconMap);
     iconMap.load("/opt/qspot/images/icon-type-song-color-offline.png"); //load song (track) offline type icon from file
     QIcon trackTypeOfflineIcon(iconMap);
+    iconMap.load("/opt/qspot/images/icon-type-song-starred.png"); //load song (track) type icon from file
+    QIcon trackTypeStarredIcon(iconMap);
+    iconMap.load("/opt/qspot/images/icon-type-song-starred-offline.png"); //load song (track) type icon from file
+    QIcon trackTypeStarredOfflineIcon(iconMap);
 
     //appends new track item to the track list model
     QStandardItem *trackItem = new QStandardItem();
     trackItem->setEditable(false);
     strSubHeader = "";
-    if(!track->isOffline()) //track not available offline
-        trackItem->setData(trackTypeIcon,ListViewDelegate::iconRole);
-    else //track available offline
-        trackItem->setData(trackTypeOfflineIcon,ListViewDelegate::iconRole);
+    if(track->isStarred()) //starred track
+    {
+        if(!track->isOffline()) //track not available offline
+            trackItem->setData(trackTypeStarredIcon,ListViewDelegate::iconRole);
+         else //track available offline
+            trackItem->setData(trackTypeStarredOfflineIcon,ListViewDelegate::iconRole);
+    }
+    else
+    {
+        if(!track->isOffline()) //track not available offline
+            trackItem->setData(trackTypeIcon,ListViewDelegate::iconRole);
+         else //track available offline
+            trackItem->setData(trackTypeOfflineIcon,ListViewDelegate::iconRole);
+    }
     trackItem->setData(track->getName(),ListViewDelegate::headerRole);
     trackItem->setData(track->getDurationAsString(),ListViewDelegate::subHeaderRightJustifyRole);
     trackItem->setData(pos,Qt::UserRole); //associate position in track instances list with list item */
