@@ -14,4 +14,7 @@
 #define IDX_BITRATE_160k 1
 #define IDX_BITRATE_320k 2
 
+#define FORCE_OFFLINE_MODE_OFF 0 //force offline mode OFF (default option)
+#define FORCE_OFFLINE_MODE_ON  1 //force offline mode ON
+
 #endif // GLOBAL_DEFS_H
