@@ -56,8 +56,8 @@ MainWindow::MainWindow(QWidget *parent)
     }
 
     m_pLastFMScrobbler = new LastFMScrobbler(this); //allocate Last.fm scrobbler instance
-    m_pLastFMScrobbler->setAPIKey("f950a6e7870997ea77cb0ecc9c8fb962"); //set associated Last.fm API key
-    m_pLastFMScrobbler->setSecret("48875d761d06f7b0efd37304e0226e9f"); //set associated Last.fm shared secret
+    m_pLastFMScrobbler->setAPIKey(CredManager::getLastFmAPIKey()); //set associated Last.fm API key
+    m_pLastFMScrobbler->setSecret(CredManager::getLastFmSecret()); //set associated Last.fm shared secret
     m_pLastFMScrobbler->setUserAgent("QSpot " + QString(APP_VERSION)); //set client user agent
     m_pLastFMScrobbler->setCachePath("/home/user/");
     connect(m_pLastFMScrobbler,SIGNAL(authenticateSessionStatus(bool,const QString&)),SLOT(OnScrobblingStatus(bool, const QString&)));
@@ -611,10 +611,16 @@ void MainWindow::OnLoginResponse(Spotify::Error error)
  void MainWindow::OnPlaylistAdded(Spotify::Playlist* playlist, qint32 position)
  {
      //a playlist has been added
+     qint32 insertPos;
+
      if(playlist)
      {   //connect updated signal
          connect(playlist,SIGNAL(updated()),this,SLOT(OnPlaylistUpdated()));
-         m_Playlists.insert(position,playlist); //insert into corresponding pos in list
+         if(m_pSession->getStarredPlaylist())
+             insertPos = position + 1;
+         else
+             insertPos = position;
+         m_Playlists.insert(insertPos,playlist); //insert into corresponding pos in list
          updatePlaylistModel(); //update playlists model
      }
  }
@@ -622,10 +628,15 @@ void MainWindow::OnLoginResponse(Spotify::Error error)
   void MainWindow::OnPlaylistRemoved(qint32 position)
   {
       //a playlist has been removed
+      qint32 rmPos;
 
       if(position<m_Playlists.size())
       {
-          Spotify::Playlist* playlist = m_Playlists.takeAt(position);
+          if(m_pSession->getStarredPlaylist())
+              rmPos = position + 1;
+          else
+              rmPos = position;
+          Spotify::Playlist* playlist = m_Playlists.takeAt(rmPos);
           if(playlist)
           {
               disconnect(playlist,SIGNAL(updated()),this,SLOT(OnPlaylistUpdated())); //disconnect signal / slot
@@ -650,11 +661,17 @@ void MainWindow::updatePlaylistModel()
 {
     //update the listmodel from underlying playlist instances
 
+
+    //load delegate icons
     QPixmap iconMap;
     iconMap.load("/opt/qspot/images/icon-type-list.png"); //load playlist type icon from file
     QIcon listTypeIcon(iconMap);
+    iconMap.load("/opt/qspot/images/icon-type-list-starred.png"); //load playlist starred type icon from file
+    QIcon listTypeStarredIcon(iconMap);
     iconMap.load("/opt/qspot/images/icon-type-list-offline.png"); //load playlist type (offline) icon from file
     QIcon listTypeOfflineIcon(iconMap);
+    iconMap.load("/opt/qspot/images/icon-type-list-starred-offline.png"); //load playlist starred type (offline) icon from file
+    QIcon listTypeStarredOfflineIcon(iconMap);
 
     m_pPlaylistModel->clear();
 
@@ -669,10 +686,20 @@ void MainWindow::updatePlaylistModel()
         {
             QStandardItem *item = new QStandardItem();
             item->setEditable(false);
-            if(pl->getOfflineStatus()!=Spotify::Available) //playlist not available offline
-                item->setData(listTypeIcon,ListViewDelegate::iconRole);
+            if(pl->getType()==PLAYLIST_TYPE_STARRED) //playlist containing user's starred tracks
+            {
+                if(pl->getOfflineStatus()!=Spotify::Available) //playlist not available offline
+                    item->setData(listTypeStarredIcon,ListViewDelegate::iconRole);
+                else
+                    item->setData(listTypeStarredOfflineIcon,ListViewDelegate::iconRole);  //offline playlist
+            }
             else
-                item->setData(listTypeOfflineIcon,ListViewDelegate::iconRole);  //offline playlist
+            {
+                if(pl->getOfflineStatus()!=Spotify::Available) //playlist not available offline
+                    item->setData(listTypeIcon,ListViewDelegate::iconRole);
+                else
+                    item->setData(listTypeOfflineIcon,ListViewDelegate::iconRole);  //offline playlist
+            }
             item->setData(pl->getName(),ListViewDelegate::headerRole);
             item->setData(QString::number(pl->getNumTracks()) + " " + tr("tracks"),ListViewDelegate::subHeaderLeftJustifyRole);
             item->setData(pos,ListViewDelegate::customDataRole); //store associated position in playlist instance list
@@ -686,6 +713,13 @@ void MainWindow::OnPlaylistContainersReady(QList<Spotify::Playlist*> playlists)
    //add items to playlists list widget (all user's playlists have successfully loaded)
 
    m_Playlists = playlists; //store list of playlists
+
+   if(m_pSession->getStarredPlaylist())
+   {
+       //prepand the user's starred tracks playlist
+       m_Playlists.prepend(m_pSession->getStarredPlaylist());
+   }
+
    for(qint32 pos=0; pos < m_Playlists.size(); pos++)
    {
        //setup signal / slot connections (for notification of playlist metadata / state updated)
