@@ -1,6 +1,6 @@
 #ifndef ALBUM_H
 #define ALBUM_H
-#include <spotify/api.h>
+#include <libspotify/api.h>
 #include "artist.h"
 #include "imagecontainer.h"
 
