@@ -19,7 +19,5 @@ QString Spotify::Error::toString() const
 
 bool Spotify::Error::isError() const
 {
-    if(m_error != SP_ERROR_OK)
-        qDebug() << "Error code: " << m_error;
     return ( m_error != SP_ERROR_OK );
 }
