@@ -16,7 +16,7 @@ Spotify::Session::Session( QObject* parent ):
     m_userReqLogout ( false ),
     m_offlineMode( false ),
     m_offlineModeForced ( false ),
-    m_connRules ( (sp_connection_rules)(SP_CONNECTION_RULE_ALLOW_SYNC_OVER_WIFI| SP_CONNECTION_RULE_NETWORK_IF_ROAMING) ),
+    m_connRules ( (sp_connection_rules)(SP_CONNECTION_RULE_ALLOW_SYNC_OVER_WIFI| SP_CONNECTION_RULE_NETWORK | SP_CONNECTION_RULE_NETWORK_IF_ROAMING) ),
     m_connState( SP_CONNECTION_STATE_UNDEFINED ),
     m_allPlaylistsLoaded( false ),
     m_pAudioThread ( 0 ),
@@ -24,7 +24,8 @@ Spotify::Session::Session( QObject* parent ):
     m_playbackPos( 0 ),
     m_bufferedAmount( 0 ),
     m_audioFragmentBuffer ( QByteArray () ),
-    m_framesConsumed ( 0 )
+    m_framesConsumed ( 0 ),
+    m_pStarredPlaylist ( 0 )
 {
     //Register meta types
     qRegisterMetaType<Spotify::Error>("Spotify::Error");
@@ -82,9 +83,14 @@ QString Spotify::Session::getRememberedUser()
     {
         qint32 ret = sp_session_remembered_user(m_session,userID,sizeof(userID));
         if(ret!=-1)
-            return QString::fromUtf8(userID);
+        {
+            return QString::fromUtf8((const char*)userID,sizeof(userID));
+        }
         else
+        {
+            qDebug() << "No stored credentials..";
             return QString();
+        }
     }
     else
         qDebug() << "No valid session!";
@@ -125,6 +131,12 @@ bool Spotify::Session::getOfflineTimeLeft(qint32& days, qint32& hours, qint32& m
     return false;
 }
 
+Spotify::Playlist* Spotify::Session::getStarredPlaylist()
+{
+    //Returns (pointer) to the playlist containing user's starred tracks (or NULL in case error has occured in allocating the playlist).
+    return m_pStarredPlaylist;
+}
+
 void Spotify::Session::init()
 {
     //Init the current Spotify session.
@@ -160,8 +172,8 @@ void Spotify::Session::init()
     m_config.api_version = SPOTIFY_API_VERSION;
     m_config.cache_location = cachePath.data();
     m_config.settings_location = settingsPath.data();
-    m_config.application_key = g_appkey;
-    m_config.application_key_size = g_appkey_size;
+    m_config.application_key = CredManager::getSpotifyAPIKey();
+    m_config.application_key_size = CredManager::getSpotifyAPIKeySize();
     m_config.device_id = "N900";
     m_config.user_agent = "QSpot";
     m_config.tracefile = NULL;
@@ -222,8 +234,7 @@ void Spotify::Session::setNetworkState()
        }
 
        setConnectionType(connType); //set current connection type
-
-       setConnectionRule(SP_CONNECTION_RULE_NETWORK,!m_offlineMode); //allow / disallow network activity depending on offline mode flag
+       setOfflineMode(false,false);
     }
 }
 
@@ -371,6 +382,9 @@ void Spotify::Session::setConnectionRule(sp_connection_rules rule, bool state)
 
      if(m_offlineMode!=offline)
      {
+         if(m_offlineModeForced && !offline && !userRequested)
+             return;
+
          if(!offline)
          { //online mode requested; establish network connection in case we are not already connected
              bStatus = m_pConnMan->attemptConnect();
@@ -740,7 +754,7 @@ void Spotify::Session::updateMetadata()
             //add initially empty playlist container instances
             for(qint32 pos = 0; pos < sp_playlistcontainer_num_playlists( m_playlistcontainer ); pos++)
             {
-                Spotify::Playlist* playlist = new Spotify::Playlist(m_session, sp_playlistcontainer_playlist(m_playlistcontainer, pos), this);
+                Spotify::Playlist* playlist = new Spotify::Playlist(m_session, PLAYLIST_TYPE_USER, sp_playlistcontainer_playlist(m_playlistcontainer, pos), this);
                 m_playlistList.insert(pos, playlist); //insert container instance into list
                 m_playlistHash.insert(playlist->getPlaylist(),playlist);
             }
@@ -940,10 +954,11 @@ void Spotify::Session::OnPlayListAdded(sp_playlist* playlist, qint32 position)
     //Playlist has been added to root playlist container
 
    qDebug()<< "Playlist added";
+   qint32 insertPos;
 
    if(!m_playlistHash.contains(playlist))
    {//playlist not already added
-       Spotify::Playlist* pl = new Spotify::Playlist(m_session, playlist);
+       Spotify::Playlist* pl = new Spotify::Playlist(m_session, PLAYLIST_TYPE_USER, playlist);
        pl->setParent( this );
        pl->setPosition( position );
        m_playlistHash.insert( playlist, pl );
@@ -1026,7 +1041,7 @@ void Spotify::Session::OnRootListContainerLoaded(sp_playlistcontainer* pc)
      //add initially empty playlist container instances
      for(qint32 pos = 0; pos < sp_playlistcontainer_num_playlists( pc ); pos++)
         {
-                 Spotify::Playlist* playlist = new Spotify::Playlist(m_session, sp_playlistcontainer_playlist(pc, pos), this);
+         Spotify::Playlist* playlist = new Spotify::Playlist(m_session, PLAYLIST_TYPE_USER, sp_playlistcontainer_playlist(pc, pos), this);
 		 m_playlistList.insert(pos, playlist); //insert container instance into list
 	 }
 
@@ -1155,6 +1170,16 @@ void Spotify::Session::loggedInWrapper( Spotify::Error error )
         m_playlistcontainer = sp_session_playlistcontainer(m_session); //get root playlist container
         sp_playlistcontainer_add_callbacks(m_playlistcontainer,&pc_callbacks,NULL); //register callbacks
         qDebug() << "Container callbacks registered..";
+        //allocate the playlist containing currenly logged-in user's starred tracks
+        sp_playlist* starred_pl = sp_session_starred_create(m_session);
+        if(starred_pl)
+        {
+            m_pStarredPlaylist = new Spotify::Playlist(m_session, PLAYLIST_TYPE_STARRED, starred_pl, this);
+            if(m_pStarredPlaylist)
+            {
+                m_pStarredPlaylist->setHasRef(true); //corresponding sp_playlist needs to be explicitly released
+            }
+        }
     }
 
     emit loggedIn( error );
