@@ -5,6 +5,7 @@
 #define SPOTIFYSESSION_H
 
 #include <libspotify/api.h>
+#include <credmanager.h>
 #include <QMetaType>
 #include <QDebug>
 #include <QDir>
@@ -17,7 +18,6 @@
 #include <QThread>
 #include <QWaitCondition>
 #include <QMutex>
-#include "version.h"
 #include "error.h"
 #include "track.h"
 #include "playlist.h"
@@ -93,7 +93,8 @@ namespace Spotify
             QString getCurrentUser(); //Returns the currently username for the currently logged-in user
 
             bool getOfflineTimeLeft(qint32& days, qint32& hours, qint32& minutes); //Returns time until the offline keystore expires and user is required to go online (days, hours, and minutes
-                                                                                   //left as ref. params). Returns true on success; false on error.
+
+            Spotify::Playlist* getStarredPlaylist(); //returns (pointer) to the playlist containing user's starred tracks (or NULL in case error has occured in allocating the playlist).//left as ref. params). Returns true on success; false on error.
 
             void setAllowMobileSync(bool allow); //Set whether offline syncing is allowed over mobile (e.g., 2G/3G) connections
 
@@ -559,6 +560,9 @@ namespace Spotify
             // For maintaing a sorted (by index) list of Spotify::Playlist pointers
             QList< Spotify::Playlist* > m_playlistList;
 
+            //playlist instance holding user's starred tracks
+            Spotify::Playlist* m_pStarredPlaylist;
+
             // For mapping sp_search pointers to Spotify::Search pointers
             QHash< sp_search*, Spotify::Search* > m_searchHash;
 
