@@ -25,6 +25,7 @@ namespace Spotify
             bool isLoaded() const { return m_loaded; }
             bool isAvailable() const { return m_available; }
             bool isOffline() { return m_isOffline; }
+            bool isStarred() { return m_isStarred; }
             Spotify::Artist* getArtist() { return m_artist; }
             Spotify::Album* getAlbum() { return m_album; }
             QString getName() { return m_name; }
@@ -46,6 +47,7 @@ namespace Spotify
             bool m_loaded;
             bool m_available;
             bool m_isOffline;
+            bool m_isStarred;
             Spotify::Artist* m_artist;
             Spotify::Album* m_album;
             QString m_name;
