@@ -24,12 +24,14 @@
         <translation>Album Überblick</translation>
     </message>
     <message>
-        <location filename="../src/AlbumView.cpp" line="101"/>
+        <location filename="../src/AlbumView.cpp" line="102"/>
+        <location filename="../src/AlbumView.cpp" line="104"/>
         <source>Fetching of album details failed!</source>
         <translation>Herunterladen von Album Informationen ist fehlgeschlagen!</translation>
     </message>
     <message>
-        <location filename="../src/AlbumView.cpp" line="134"/>
+        <location filename="../src/AlbumView.cpp" line="141"/>
+        <location filename="../src/AlbumView.cpp" line="143"/>
         <source>Fetching of album details failed: </source>
         <translation>Herunterladen von Album Informationen ist fehlgeschlagen: </translation>
     </message>
@@ -52,17 +54,20 @@
         <translation>Biografie</translation>
     </message>
     <message>
-        <location filename="../src/artistview.cpp" line="81"/>
+        <location filename="../src/artistview.cpp" line="82"/>
+        <location filename="../src/artistview.cpp" line="84"/>
         <source>Fetching of artist details failed!</source>
         <translation>Herunterladen von Küunstler Informationen ist fehlgeschlagen!</translation>
     </message>
     <message>
-        <location filename="../src/artistview.cpp" line="86"/>
+        <location filename="../src/artistview.cpp" line="92"/>
+        <location filename="../src/artistview.cpp" line="95"/>
         <source>Loading </source>
         <translation>Laden</translation>
     </message>
     <message>
-        <location filename="../src/artistview.cpp" line="106"/>
+        <location filename="../src/artistview.cpp" line="117"/>
+        <location filename="../src/artistview.cpp" line="119"/>
         <source>Fetching of artist details failed: </source>
         <translation>Herunterladen von Küunstler Informationen ist fehlgeschlagen: </translation>
     </message>
@@ -70,217 +75,257 @@
 <context>
     <name>LoginDialog</name>
     <message>
-        <location filename="../src/logindialog.cpp" line="21"/>
+        <location filename="../src/logindialog.cpp" line="13"/>
         <source>QSpot - Login</source>
         <translation>QSpot - Anmeldung</translation>
     </message>
     <message>
-        <location filename="../src/logindialog.cpp" line="24"/>
+        <location filename="../src/logindialog.cpp" line="16"/>
         <source>UserID:</source>
         <translation>Benutzername:</translation>
     </message>
     <message>
-        <location filename="../src/logindialog.cpp" line="26"/>
+        <location filename="../src/logindialog.cpp" line="18"/>
         <source>Password:</source>
         <translation>Passwort:</translation>
     </message>
     <message>
-        <location filename="../src/logindialog.cpp" line="29"/>
-        <location filename="../src/logindialog.cpp" line="180"/>
         <source>Remember UserID and password</source>
-        <translation>Benutzernamen und Passwort speichern</translation>
+        <translation type="obsolete">Benutzernamen und Passwort speichern</translation>
     </message>
     <message>
-        <location filename="../src/logindialog.cpp" line="35"/>
         <source>Low bitrate (96kbps)</source>
-        <translation>Niedriege Bit Rate (96kb/s)</translation>
+        <translation type="obsolete">Niedriege Bit Rate (96kb/s)</translation>
     </message>
     <message>
-        <location filename="../src/logindialog.cpp" line="35"/>
         <source>Standard bitrate (160kbps)</source>
-        <translation>Standard Bit Rate (160kb/s)</translation>
+        <translation type="obsolete">Standard Bit Rate (160kb/s)</translation>
     </message>
     <message>
-        <location filename="../src/logindialog.cpp" line="36"/>
         <source>High bitrate (320kbps)</source>
-        <translation>Hohe Bit Rate (320kb/s)</translation>
+        <translation type="obsolete">Hohe Bit Rate (320kb/s)</translation>
     </message>
     <message>
-        <location filename="../src/logindialog.cpp" line="44"/>
         <source>Preferred bitrate</source>
-        <translation>Bevorzugte Bit Rate</translation>
+        <translation type="obsolete">Bevorzugte Bit Rate</translation>
     </message>
     <message>
-        <location filename="../src/logindialog.cpp" line="48"/>
+        <location filename="../src/logindialog.cpp" line="21"/>
         <source>Login</source>
         <translation>Anmelden</translation>
     </message>
     <message>
-        <location filename="../src/logindialog.cpp" line="186"/>
         <source>Remember UserID &amp;&amp; Pwd</source>
-        <translation>Benutzer &amp; Passwort speichern</translation>
+        <translation type="obsolete">Benutzer &amp; Passwort speichern</translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/MainWindow.cpp" line="18"/>
+        <location filename="../src/MainWindow.cpp" line="16"/>
         <source>QSpot - Playlists</source>
         <translation>QSpot - Playlisten</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="62"/>
-        <location filename="../src/MainWindow.cpp" line="570"/>
+        <location filename="../src/MainWindow.cpp" line="67"/>
+        <location filename="../src/MainWindow.cpp" line="721"/>
         <source>Settings</source>
         <translation>Einstellungen</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="63"/>
-        <location filename="../src/MainWindow.cpp" line="576"/>
+        <location filename="../src/MainWindow.cpp" line="69"/>
+        <location filename="../src/MainWindow.cpp" line="727"/>
         <source>FM Transmitter</source>
         <translation>FM Transmitter</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="64"/>
-        <location filename="../src/MainWindow.cpp" line="580"/>
+        <location filename="../src/MainWindow.cpp" line="71"/>
+        <location filename="../src/MainWindow.cpp" line="731"/>
         <source>About</source>
         <translation>Über</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="179"/>
+        <location filename="../src/MainWindow.cpp" line="239"/>
+        <location filename="../src/MainWindow.cpp" line="241"/>
+        <source>Logging in to Spotify</source>
+        <translation>Anmeldung bei Spotify</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="266"/>
         <source>About QSpot</source>
         <translation>Über QSpot</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="181"/>
+        <location filename="../src/MainWindow.cpp" line="268"/>
         <source>QSpot version </source>
         <translation>QSpot Version</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="181"/>
         <source>An open-source Qt-based Spotify client for the N900/Maemo5 (based on libopenspotify).
 
 (C) 2011 Andreas Enbacka and The QSpot Team.
 
 Special thanks to Markus (markusm@tmo) for assistance with the graphical design and layout, and to Tomi (rantom@tmo) for the Finnish translations.</source>
-        <translation>Ein open-source Qt-basierter Spotify client fuer das N900/Maemo5 (basierend auf libopenspotify).
+        <translation type="obsolete">Ein open-source Qt-basierter Spotify client fuer das N900/Maemo5 (basierend auf libopenspotify).
 
 (C) 2011 Andreas Enbacka und das QSpot Team.
 
 Besonderen Dank an Markus (markusm@tmo) für Hilfe mit dem graphischem layout und Tomi (rantom@tmo) für die Finnische Übersetzung.</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="406"/>
+        <location filename="../src/MainWindow.cpp" line="214"/>
+        <location filename="../src/MainWindow.cpp" line="224"/>
+        <location filename="../src/MainWindow.cpp" line="524"/>
         <source>Error:</source>
         <translation>Fehler:</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="419"/>
+        <location filename="../src/MainWindow.cpp" line="224"/>
+        <source>No suitable internet access point(s) found!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="268"/>
+        <source>An open-source Qt-based Spotify client for the N900/Maemo5 (based on libopenspotify).
+
+(C) 2011 Andreas Enbacka and The QSpot Team.
+
+Special thanks to Markus (markusm@tmo) for assistance with the graphical design and layout, and to Tomi (rantom@tmo), Florian (florian@tmo) and Benno (bartus@tmo) for the translations.</source>
+        <translation>Ein open-source Qt-basierter Spotify client fuer das N900/Maemo5 (basierend auf libopenspotify).
+
+(C) 2011 Andreas Enbacka und das QSpot Team.
+
+Besonderen Dank an Markus (markusm@tmo) für Hilfe mit dem graphischem layout und Tomi (rantom@tmo), Florian (florian@tmo) and Benno (bartus@tmo) für die Übersetzungen.</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="544"/>
+        <location filename="../src/MainWindow.cpp" line="546"/>
         <source>Loading playlists</source>
         <translation>Laden der Playlists</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="436"/>
+        <location filename="../src/MainWindow.cpp" line="570"/>
+        <location filename="../src/MainWindow.cpp" line="573"/>
         <source>Timeout occured while loading playlists!</source>
         <translation>Timeout beim laden der Playlists überschritten!</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="464"/>
+        <location filename="../src/MainWindow.cpp" line="603"/>
         <source>tracks</source>
         <translation>Lieder</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="602"/>
+        <location filename="../src/MainWindow.cpp" line="754"/>
+        <location filename="../src/MainWindow.cpp" line="757"/>
         <source>Searching</source>
         <translation>Suchen</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="608"/>
-        <location filename="../src/MainWindow.cpp" line="623"/>
+        <location filename="../src/MainWindow.cpp" line="763"/>
+        <location filename="../src/MainWindow.cpp" line="766"/>
+        <location filename="../src/MainWindow.cpp" line="782"/>
+        <location filename="../src/MainWindow.cpp" line="784"/>
         <source>Error: </source>
         <translation>Fehler:</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="642"/>
+        <location filename="../src/MainWindow.cpp" line="805"/>
+        <location filename="../src/MainWindow.cpp" line="807"/>
         <source>No tracks found!</source>
         <translation>Keine Titel gefunden!</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="656"/>
+        <location filename="../src/MainWindow.cpp" line="825"/>
+        <location filename="../src/MainWindow.cpp" line="827"/>
         <source>Playback paused due to the same account being used somewhere else!</source>
         <translation>Wiedergabe pausiert da das gleiche Account wo anders genutzt wird!</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="666"/>
+        <location filename="../src/MainWindow.cpp" line="840"/>
+        <location filename="../src/MainWindow.cpp" line="842"/>
         <source>Last.fm error: </source>
         <translation>Last.fm Fehler:</translation>
     </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="940"/>
+        <location filename="../src/MainWindow.cpp" line="942"/>
+        <source>Failed to re-authenticate with Spotify</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QueueView</name>
     <message>
         <location filename="../src/QueueView.cpp" line="15"/>
-        <location filename="../src/QueueView.cpp" line="859"/>
-        <location filename="../src/QueueView.cpp" line="868"/>
-        <location filename="../src/QueueView.cpp" line="1012"/>
+        <location filename="../src/QueueView.cpp" line="915"/>
+        <location filename="../src/QueueView.cpp" line="924"/>
+        <location filename="../src/QueueView.cpp" line="1084"/>
         <source>Now Playing</source>
         <translation>Wiedergabe</translation>
     </message>
     <message>
-        <location filename="../src/QueueView.cpp" line="179"/>
+        <location filename="../src/QueueView.cpp" line="181"/>
         <source>Play Album</source>
         <translation>Album wiedergeben</translation>
     </message>
     <message>
-        <location filename="../src/QueueView.cpp" line="182"/>
+        <location filename="../src/QueueView.cpp" line="184"/>
         <source>Browse Album</source>
         <translation>Album durchsuchen</translation>
     </message>
     <message>
-        <location filename="../src/QueueView.cpp" line="185"/>
+        <location filename="../src/QueueView.cpp" line="187"/>
         <source>Browse Artist</source>
         <translation>Künstler durchsuchen</translation>
     </message>
     <message>
-        <location filename="../src/QueueView.cpp" line="199"/>
-        <location filename="../src/QueueView.cpp" line="206"/>
+        <location filename="../src/QueueView.cpp" line="202"/>
+        <location filename="../src/QueueView.cpp" line="210"/>
         <source>FM Transmitter</source>
         <translation>FM Transmitter</translation>
     </message>
     <message>
-        <location filename="../src/QueueView.cpp" line="386"/>
-        <location filename="../src/QueueView.cpp" line="518"/>
-        <location filename="../src/QueueView.cpp" line="803"/>
-        <location filename="../src/QueueView.cpp" line="822"/>
+        <location filename="../src/QueueView.cpp" line="395"/>
+        <location filename="../src/QueueView.cpp" line="397"/>
+        <location filename="../src/QueueView.cpp" line="542"/>
+        <location filename="../src/QueueView.cpp" line="544"/>
+        <location filename="../src/QueueView.cpp" line="852"/>
+        <location filename="../src/QueueView.cpp" line="854"/>
+        <location filename="../src/QueueView.cpp" line="875"/>
+        <location filename="../src/QueueView.cpp" line="877"/>
         <source>Error starting track playback: </source>
         <translation>Fehler beim starten der Wiedergabe: </translation>
     </message>
     <message>
-        <location filename="../src/QueueView.cpp" line="514"/>
+        <location filename="../src/QueueView.cpp" line="533"/>
+        <location filename="../src/QueueView.cpp" line="535"/>
         <source>Buffering</source>
         <translation>Puffern</translation>
     </message>
     <message>
-        <location filename="../src/QueueView.cpp" line="868"/>
-        <location filename="../src/QueueView.cpp" line="872"/>
-        <location filename="../src/QueueView.cpp" line="1012"/>
-        <location filename="../src/QueueView.cpp" line="1045"/>
+        <location filename="../src/QueueView.cpp" line="924"/>
+        <location filename="../src/QueueView.cpp" line="928"/>
+        <location filename="../src/QueueView.cpp" line="1084"/>
+        <location filename="../src/QueueView.cpp" line="1117"/>
         <source>Shuffle</source>
         <translatorcomment>Not sure about this one.</translatorcomment>
         <translation>Durcheinander</translation>
     </message>
     <message>
-        <location filename="../src/QueueView.cpp" line="933"/>
+        <location filename="../src/QueueView.cpp" line="990"/>
+        <location filename="../src/QueueView.cpp" line="993"/>
         <source>Loading album tracks</source>
         <translation>Laden der Album Titel</translation>
     </message>
     <message>
-        <location filename="../src/QueueView.cpp" line="954"/>
+        <location filename="../src/QueueView.cpp" line="1016"/>
+        <location filename="../src/QueueView.cpp" line="1018"/>
         <source>Fetching of album tracks failed: </source>
         <translation>Laden der Album Titel fehlgeschlagen: </translation>
     </message>
     <message>
-        <location filename="../src/QueueView.cpp" line="960"/>
+        <location filename="../src/QueueView.cpp" line="1027"/>
+        <location filename="../src/QueueView.cpp" line="1029"/>
         <source>Failed to load tracks!</source>
         <translation>Laden der Titel fehlgeschlagen!</translation>
     </message>
@@ -288,158 +333,198 @@ Besonderen Dank an Markus (markusm@tmo) für Hilfe mit dem graphischem layout un
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="62"/>
+        <location filename="../src/SettingsDialog.cpp" line="191"/>
+        <location filename="../src/SettingsDialog.cpp" line="219"/>
+        <source>Remember UserID and password</source>
+        <translation>Benutzernamen und Passwort speichern</translation>
+    </message>
+    <message>
+        <location filename="../src/SettingsDialog.cpp" line="49"/>
+        <source>Low bitrate (96kbps)</source>
+        <translation>Niedriege Bit Rate (96kb/s)</translation>
+    </message>
+    <message>
+        <location filename="../src/SettingsDialog.cpp" line="49"/>
+        <source>Standard bitrate (160kbps)</source>
+        <translation>Standard Bit Rate (160kb/s)</translation>
+    </message>
+    <message>
+        <location filename="../src/SettingsDialog.cpp" line="50"/>
+        <source>High bitrate (320kbps)</source>
+        <translation>Hohe Bit Rate (320kb/s)</translation>
+    </message>
+    <message>
+        <location filename="../src/SettingsDialog.cpp" line="95"/>
         <source>Landscape</source>
         <translation>Querformat</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="62"/>
+        <location filename="../src/SettingsDialog.cpp" line="95"/>
         <source>Portrait</source>
         <translation>Hochformat</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="62"/>
+        <location filename="../src/SettingsDialog.cpp" line="95"/>
         <source>Automatic</source>
         <translation>Automatisch</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="118"/>
-        <location filename="../src/SettingsDialog.cpp" line="142"/>
+        <location filename="../src/SettingsDialog.cpp" line="169"/>
+        <location filename="../src/SettingsDialog.cpp" line="198"/>
         <source>QSpot - Settings</source>
         <translation>QSpot - Einstellungen</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="119"/>
+        <location filename="../src/SettingsDialog.cpp" line="170"/>
         <source>Max. tracks returned</source>
         <translation>Max. Lieder laden</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="120"/>
+        <location filename="../src/SettingsDialog.cpp" line="171"/>
         <source>Max. albums returned</source>
         <translation>Max. Alben laden</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="121"/>
+        <location filename="../src/SettingsDialog.cpp" line="172"/>
         <source>Max. artists returned</source>
         <translation>Max. Künstler laden</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="122"/>
-        <location filename="../src/SettingsDialog.cpp" line="146"/>
+        <location filename="../src/SettingsDialog.cpp" line="173"/>
+        <location filename="../src/SettingsDialog.cpp" line="202"/>
         <source>Search settings</source>
         <translation>Such Einstellungen</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="123"/>
-        <location filename="../src/SettingsDialog.cpp" line="147"/>
+        <location filename="../src/SettingsDialog.cpp" line="174"/>
+        <location filename="../src/SettingsDialog.cpp" line="203"/>
         <source>Buffering settings</source>
         <translation>Puffer Einstellungen</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="124"/>
+        <location filename="../src/SettingsDialog.cpp" line="175"/>
         <source>Min. buffering length (secs)</source>
         <translation>Min. Puffer Dauer (sek.)</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="125"/>
+        <location filename="../src/SettingsDialog.cpp" line="176"/>
         <source>Enable track pre-buffering</source>
         <translation>Titel vor-puffern aktivieren</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="126"/>
-        <location filename="../src/SettingsDialog.cpp" line="150"/>
+        <location filename="../src/SettingsDialog.cpp" line="178"/>
+        <location filename="../src/SettingsDialog.cpp" line="207"/>
+        <source>Preferred bitrate</source>
+        <translation>Bevorzugte Bit Rate</translation>
+    </message>
+    <message>
+        <location filename="../src/SettingsDialog.cpp" line="179"/>
+        <location filename="../src/SettingsDialog.cpp" line="208"/>
         <source>UI Language</source>
         <translation>UI Sprache</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="127"/>
-        <location filename="../src/SettingsDialog.cpp" line="151"/>
+        <location filename="../src/SettingsDialog.cpp" line="180"/>
+        <location filename="../src/SettingsDialog.cpp" line="209"/>
         <source>Display orientation</source>
         <translation>Display Orientierung</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="128"/>
-        <location filename="../src/SettingsDialog.cpp" line="152"/>
+        <location filename="../src/SettingsDialog.cpp" line="182"/>
+        <location filename="../src/SettingsDialog.cpp" line="211"/>
         <source>Playlist options</source>
         <translation>Playlisten Optionen</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="129"/>
+        <location filename="../src/SettingsDialog.cpp" line="183"/>
         <source>Playlist load timeout (secs)</source>
         <translation>Playlisten Lade-Timeout (sek.)</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="130"/>
-        <location filename="../src/SettingsDialog.cpp" line="154"/>
+        <location filename="../src/SettingsDialog.cpp" line="184"/>
+        <location filename="../src/SettingsDialog.cpp" line="213"/>
         <source>Pause on headset unplugged</source>
         <translation>Pausieren wenn Headset ausgestöpselt wird</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="131"/>
-        <location filename="../src/SettingsDialog.cpp" line="155"/>
+        <location filename="../src/SettingsDialog.cpp" line="185"/>
+        <location filename="../src/SettingsDialog.cpp" line="214"/>
         <source>Scrobbling options</source>
         <translation>Scrobbling Optionen</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="132"/>
+        <location filename="../src/SettingsDialog.cpp" line="186"/>
         <source>Enable scrobbling to Last.fm</source>
         <translation>Last.fm scrobbling aktivieren</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="133"/>
-        <location filename="../src/SettingsDialog.cpp" line="157"/>
+        <location filename="../src/SettingsDialog.cpp" line="187"/>
+        <location filename="../src/SettingsDialog.cpp" line="216"/>
         <source>Last.fm username</source>
         <translation>Last.fm Benutzername</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="134"/>
-        <location filename="../src/SettingsDialog.cpp" line="158"/>
+        <location filename="../src/SettingsDialog.cpp" line="188"/>
+        <location filename="../src/SettingsDialog.cpp" line="217"/>
         <source>Last.fm password</source>
         <translation>Last.fm Passwort</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="135"/>
-        <location filename="../src/SettingsDialog.cpp" line="159"/>
+        <location filename="../src/SettingsDialog.cpp" line="189"/>
+        <location filename="../src/SettingsDialog.cpp" line="218"/>
         <source>Save</source>
         <translation>Speichern</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="143"/>
+        <location filename="../src/SettingsDialog.cpp" line="190"/>
+        <location filename="../src/SettingsDialog.cpp" line="220"/>
+        <source>Hide coverart in Now Playing</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/SettingsDialog.cpp" line="199"/>
         <source>Max. tracks</source>
         <translation>Max. Titel</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="144"/>
+        <location filename="../src/SettingsDialog.cpp" line="200"/>
         <source>Max. albums</source>
         <translation>Max. Alben</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="145"/>
+        <location filename="../src/SettingsDialog.cpp" line="201"/>
         <source>Max. artists</source>
         <translation>Max. Künstler</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="148"/>
+        <location filename="../src/SettingsDialog.cpp" line="204"/>
         <source>Min.buff.length (secs)</source>
         <translation>Min.Puffer Länge (sek.)</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="149"/>
+        <location filename="../src/SettingsDialog.cpp" line="205"/>
         <source>Enable track pre-buff.</source>
         <translation>Titel vor-puffern akt.</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="153"/>
+        <location filename="../src/SettingsDialog.cpp" line="212"/>
         <source>Playlist load TO (secs)</source>
         <translation>Playlisten Lade-TO (sek.)</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="156"/>
+        <location filename="../src/SettingsDialog.cpp" line="215"/>
         <source>Enable Last.fm scrobbling</source>
         <translation>Last.fm scrob. aktivieren</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="275"/>
+        <location filename="../src/SettingsDialog.cpp" line="405"/>
+        <location filename="../src/SettingsDialog.cpp" line="407"/>
+        <source>Please restart QSpot for bitrate change to take effect!</source>
+        <translation>Bitte starten Sie QSpot neu um den Bit Raten wechsel anzuwenden!</translation>
+    </message>
+    <message>
+        <location filename="../src/SettingsDialog.cpp" line="421"/>
+        <location filename="../src/SettingsDialog.cpp" line="423"/>
         <source>Please restart QSpot for language change to take effect!</source>
         <translation>Bitte starten Sie QSpot neu um den Sprachwechsel anzuwenden!</translation>
     </message>
@@ -558,28 +643,31 @@ Besonderen Dank an Markus (markusm@tmo) für Hilfe mit dem graphischem layout un
         <translation>Künstler, Album, Titel (aufsteigend)</translation>
     </message>
     <message>
-        <location filename="../src/TrackView.cpp" line="81"/>
-        <location filename="../src/TrackView.cpp" line="190"/>
+        <location filename="../src/TrackView.cpp" line="83"/>
+        <location filename="../src/TrackView.cpp" line="210"/>
         <source>FM Transmitter</source>
         <translation>FM Transmitter</translation>
     </message>
     <message>
-        <location filename="../src/TrackView.cpp" line="119"/>
+        <location filename="../src/TrackView.cpp" line="124"/>
+        <location filename="../src/TrackView.cpp" line="127"/>
         <source>Loading album tracks</source>
         <translation>Laden der Album Titel</translation>
     </message>
     <message>
-        <location filename="../src/TrackView.cpp" line="155"/>
+        <location filename="../src/TrackView.cpp" line="165"/>
+        <location filename="../src/TrackView.cpp" line="167"/>
         <source>Fetching of album tracks failed: </source>
         <translation>Laden der Album Titel fehlgeschlagen: </translation>
     </message>
     <message>
-        <location filename="../src/TrackView.cpp" line="161"/>
+        <location filename="../src/TrackView.cpp" line="176"/>
+        <location filename="../src/TrackView.cpp" line="178"/>
         <source>Failed to load tracks!</source>
         <translation>Laden der Titel fehlgeschlagen!</translation>
     </message>
     <message>
-        <location filename="../src/TrackView.cpp" line="273"/>
+        <location filename="../src/TrackView.cpp" line="293"/>
         <source>Search results: </source>
         <translation>Such Ergebnisse: </translation>
     </message>
